summaryrefslogtreecommitdiff
path: root/sys/arch
diff options
context:
space:
mode:
authorJonathan Gray <jsg@cvs.openbsd.org>2020-05-25 06:45:27 +0000
committerJonathan Gray <jsg@cvs.openbsd.org>2020-05-25 06:45:27 +0000
commit3e39b250169e8ef15507000e9603f0a5558e90da (patch)
treebc7d06cc23253bebf59e60d5313c9eab983e0364 /sys/arch
parent1d7dc5e6a2e9035f5991e4762929b6cf6ec25621 (diff)
rename wsdisplay alloc_attr() to pack_attr()
Suggested by John Carmack. miod agrees a rename would make sense and explained it was initially thought drivers may need to allocate storage but in practice they don't need more than 32 bits for an attribute. ok mpi@
Diffstat (limited to 'sys/arch')
-rw-r--r--sys/arch/amd64/amd64/efifb.c6
-rw-r--r--sys/arch/armv7/exynos/exdisplay.c6
-rw-r--r--sys/arch/armv7/omap/omdisplay.c4
-rw-r--r--sys/arch/loongson/dev/radeonfb.c6
-rw-r--r--sys/arch/loongson/dev/sisfb.c6
-rw-r--r--sys/arch/loongson/dev/smfb.c6
-rw-r--r--sys/arch/luna88k/dev/lunafb.c6
-rw-r--r--sys/arch/luna88k/dev/omrasops.c10
-rw-r--r--sys/arch/macppc/macppc/ofw_machdep.c4
-rw-r--r--sys/arch/macppc/pci/vgafb.c4
-rw-r--r--sys/arch/sgi/dev/gbe.c8
-rw-r--r--sys/arch/sgi/dev/impact.c6
-rw-r--r--sys/arch/sgi/gio/grtwo.c6
-rw-r--r--sys/arch/sgi/gio/light.c6
-rw-r--r--sys/arch/sgi/gio/newport.c6
-rw-r--r--sys/arch/sgi/xbow/odyssey.c6
-rw-r--r--sys/arch/sparc64/dev/creator.c4
-rw-r--r--sys/arch/sparc64/dev/fb.c10
18 files changed, 55 insertions, 55 deletions
diff --git a/sys/arch/amd64/amd64/efifb.c b/sys/arch/amd64/amd64/efifb.c
index 69d6a01bad4..656bbd2b057 100644
--- a/sys/arch/amd64/amd64/efifb.c
+++ b/sys/arch/amd64/amd64/efifb.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: efifb.c,v 1.27 2020/01/24 05:27:31 kettenis Exp $ */
+/* $OpenBSD: efifb.c,v 1.28 2020/05/25 06:45:25 jsg Exp $ */
/*
* Copyright (c) 2015 YASUOKA Masahiko <yasuoka@yasuoka.net>
@@ -222,7 +222,7 @@ efifb_attach(struct device *parent, struct device *self, void *aux)
rasops_init(ri, efifb_std_descr.nrows, efifb_std_descr.ncols);
- ri->ri_ops.alloc_attr(ri->ri_active, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(ri->ri_active, 0, 0, 0, &defattr);
wsdisplay_cnattach(&efifb_std_descr, ri->ri_active, ccol, crow,
defattr);
}
@@ -445,7 +445,7 @@ efifb_cnattach_common(void)
efifb_std_descr.fontheight = ri->ri_font->fontheight;
efifb_std_descr.capabilities = ri->ri_caps;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &defattr);
wsdisplay_cnattach(&efifb_std_descr, ri, 0, 0, defattr);
}
diff --git a/sys/arch/armv7/exynos/exdisplay.c b/sys/arch/armv7/exynos/exdisplay.c
index a80171fcc2b..e0507d0ed06 100644
--- a/sys/arch/armv7/exynos/exdisplay.c
+++ b/sys/arch/armv7/exynos/exdisplay.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: exdisplay.c,v 1.4 2016/07/26 22:10:10 patrick Exp $ */
+/* $OpenBSD: exdisplay.c,v 1.5 2020/05/25 06:45:25 jsg Exp $ */
/*
* Copyright (c) 2013 Patrick Wildt <patrick@blueri.se>
*
@@ -152,7 +152,7 @@ exdisplay_attach(struct device *parent, struct device *self, void *args)
ri->ri_bits = (u_char *)sc->sc_fbioh;
exdisplay_setup_rasops(ri, &exdisplay_stdscreen);
- ri->ri_ops.alloc_attr(ri->ri_active, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(ri->ri_active, 0, 0, 0, &defattr);
wsdisplay_cnattach(&exdisplay_stdscreen, ri->ri_active,
0, 0, defattr);
}
@@ -184,7 +184,7 @@ exdisplay_cnattach(bus_space_tag_t iot, bus_addr_t iobase, size_t size)
exdisplay_setup_rasops(ri, descr);
/* assumes 16 bpp */
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &defattr);
wsdisplay_cnattach(descr, ri, ri->ri_ccol, ri->ri_crow, defattr);
diff --git a/sys/arch/armv7/omap/omdisplay.c b/sys/arch/armv7/omap/omdisplay.c
index 7935b36ce19..bb982a7d200 100644
--- a/sys/arch/armv7/omap/omdisplay.c
+++ b/sys/arch/armv7/omap/omdisplay.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: omdisplay.c,v 1.6 2019/05/06 03:45:58 mlarkin Exp $ */
+/* $OpenBSD: omdisplay.c,v 1.7 2020/05/25 06:45:25 jsg Exp $ */
/*
* Copyright (c) 2007 Dale Rahn <drahn@openbsd.org>
*
@@ -1170,7 +1170,7 @@ omdisplay_alloc_screen(void *v, const struct wsscreen_descr *_type,
omdisplay_setup_rasops(sc, ri);
/* assumes 16 bpp */
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, attrp);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, attrp);
*cookiep = ri;
*curxp = 0;
diff --git a/sys/arch/loongson/dev/radeonfb.c b/sys/arch/loongson/dev/radeonfb.c
index 294910452b6..18e8b36f39b 100644
--- a/sys/arch/loongson/dev/radeonfb.c
+++ b/sys/arch/loongson/dev/radeonfb.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: radeonfb.c,v 1.2 2017/01/15 20:22:33 fcambus Exp $ */
+/* $OpenBSD: radeonfb.c,v 1.3 2020/05/25 06:45:25 jsg Exp $ */
/*
* Copyright (c) 2009 Mark Kettenis.
@@ -263,7 +263,7 @@ radeonfb_alloc_screen(void *v, const struct wsscreen_descr *type,
*cookiep = ri;
*curxp = *curyp = 0;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, attrp);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, attrp);
sc->sc_nscr++;
return 0;
@@ -722,7 +722,7 @@ radeonfb_cnattach(bus_space_tag_t memt, bus_space_tag_t iot, pcitag_t tag,
return rc;
ri = &radeonfbcn.ri;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &defattr);
wsdisplay_cnattach(&radeonfbcn.wsd, ri, 0, 0, defattr);
return 0;
diff --git a/sys/arch/loongson/dev/sisfb.c b/sys/arch/loongson/dev/sisfb.c
index 4268ea1d8dc..c3c17a28927 100644
--- a/sys/arch/loongson/dev/sisfb.c
+++ b/sys/arch/loongson/dev/sisfb.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: sisfb.c,v 1.5 2017/01/15 20:22:33 fcambus Exp $ */
+/* $OpenBSD: sisfb.c,v 1.6 2020/05/25 06:45:25 jsg Exp $ */
/*
* Copyright (c) 2010 Miodrag Vallat.
@@ -278,7 +278,7 @@ sisfb_alloc_screen(void *v, const struct wsscreen_descr *type, void **cookiep,
*cookiep = ri;
*curxp = *curyp = 0;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, attrp);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, attrp);
sc->sc_nscr++;
return 0;
@@ -652,7 +652,7 @@ sisfb_cnattach(bus_space_tag_t memt, bus_space_tag_t iot, pcitag_t tag,
return rc;
ri = &sisfbcn.ri;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &defattr);
wsdisplay_cnattach(&sisfbcn.wsd, ri, 0, 0, defattr);
return 0;
diff --git a/sys/arch/loongson/dev/smfb.c b/sys/arch/loongson/dev/smfb.c
index cc104bdc234..def3d6dfc1c 100644
--- a/sys/arch/loongson/dev/smfb.c
+++ b/sys/arch/loongson/dev/smfb.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: smfb.c,v 1.17 2017/01/10 08:26:41 fcambus Exp $ */
+/* $OpenBSD: smfb.c,v 1.18 2020/05/25 06:45:25 jsg Exp $ */
/*
* Copyright (c) 2009, 2010 Miodrag Vallat.
@@ -251,7 +251,7 @@ smfb_alloc_screen(void *v, const struct wsscreen_descr *type, void **cookiep,
*cookiep = ri;
*curxp = *curyp = 0;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, attrp);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, attrp);
sc->sc_nscr++;
return 0;
@@ -721,7 +721,7 @@ smfb_cnattach(bus_space_tag_t memt, bus_space_tag_t iot, pcitag_t tag,
return rc;
ri = &smfbcn.ri;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &defattr);
wsdisplay_cnattach(&smfbcn.wsd, ri, 0, 0, defattr);
return 0;
diff --git a/sys/arch/luna88k/dev/lunafb.c b/sys/arch/luna88k/dev/lunafb.c
index 80d39488b9c..4ec577993f5 100644
--- a/sys/arch/luna88k/dev/lunafb.c
+++ b/sys/arch/luna88k/dev/lunafb.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: lunafb.c,v 1.25 2017/11/03 06:54:06 aoyama Exp $ */
+/* $OpenBSD: lunafb.c,v 1.26 2020/05/25 06:45:25 jsg Exp $ */
/* $NetBSD: lunafb.c,v 1.7.6.1 2002/08/07 01:48:34 lukem Exp $ */
/*-
@@ -221,7 +221,7 @@ omfb_cnattach(void)
long defattr;
omfb_getdevconfig(OMFB_FB_WADDR, dc);
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &defattr);
wsdisplay_cnattach(&omfb_stdscreen, ri, 0, 0, defattr);
omfb_console = 1;
return (0);
@@ -480,7 +480,7 @@ omfb_alloc_screen(void *v, const struct wsscreen_descr *type, void **cookiep,
*cookiep = ri;
*curxp = 0;
*curyp = 0;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, attrp);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, attrp);
sc->nscreens++;
return (0);
}
diff --git a/sys/arch/macppc/macppc/ofw_machdep.c b/sys/arch/macppc/macppc/ofw_machdep.c
index ed9232f80c8..23a8d2cc3f8 100644
--- a/sys/arch/macppc/macppc/ofw_machdep.c
+++ b/sys/arch/macppc/macppc/ofw_machdep.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: ofw_machdep.c,v 1.57 2019/09/03 17:51:52 deraadt Exp $ */
+/* $OpenBSD: ofw_machdep.c,v 1.58 2020/05/25 06:45:25 jsg Exp $ */
/* $NetBSD: ofw_machdep.c,v 1.1 1996/09/30 16:34:50 ws Exp $ */
/*
@@ -511,7 +511,7 @@ of_display_console(void)
fb->ofw_wsd.fontheight = ri->ri_font->fontheight;
#endif
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &defattr);
wsdisplay_cnattach(&fb->ofw_wsd, ri, 0, 0, defattr);
}
#endif
diff --git a/sys/arch/macppc/pci/vgafb.c b/sys/arch/macppc/pci/vgafb.c
index 1e9def6fcca..b18979f78be 100644
--- a/sys/arch/macppc/pci/vgafb.c
+++ b/sys/arch/macppc/pci/vgafb.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: vgafb.c,v 1.60 2014/07/28 15:00:27 jsg Exp $ */
+/* $OpenBSD: vgafb.c,v 1.61 2020/05/25 06:45:25 jsg Exp $ */
/* $NetBSD: vga.c,v 1.3 1996/12/02 22:24:54 cgd Exp $ */
/*
@@ -196,7 +196,7 @@ vgafb_console_init(struct vgafb_softc *sc)
sc->sc_wsd.fontwidth = ri->ri_font->fontwidth;
sc->sc_wsd.fontheight = ri->ri_font->fontheight;
- ri->ri_ops.alloc_attr(ri->ri_active, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(ri->ri_active, 0, 0, 0, &defattr);
wsdisplay_cnattach(&sc->sc_wsd, ri->ri_active, ri->ri_ccol, ri->ri_crow,
defattr);
diff --git a/sys/arch/sgi/dev/gbe.c b/sys/arch/sgi/dev/gbe.c
index fb862387e9c..437a7c5508b 100644
--- a/sys/arch/sgi/dev/gbe.c
+++ b/sys/arch/sgi/dev/gbe.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: gbe.c,v 1.21 2013/10/21 10:36:16 miod Exp $ */
+/* $OpenBSD: gbe.c,v 1.22 2020/05/25 06:45:25 jsg Exp $ */
/*
* Copyright (c) 2007, 2008, 2009 Joel Sing <jsing@openbsd.org>
@@ -401,7 +401,7 @@ gbe_attach(struct device *parent, struct device *self, void *aux)
/* Attach as console if necessary. */
if (strncmp(bios_console, "video", 5) == 0) {
- screen->ri.ri_ops.alloc_attr(&screen->ri, 0, 0, 0, &attr);
+ screen->ri.ri_ops.pack_attr(&screen->ri, 0, 0, 0, &attr);
wsdisplay_cnattach(&gbe_stdscreen, &screen->ri, 0, 0, attr);
gsc->console = 1;
}
@@ -964,7 +964,7 @@ gbe_alloc_screen(void *v, const struct wsscreen_descr *type, void **cookiep,
*curyp = 0;
/* Correct screen attributes. */
- screen->ri.ri_ops.alloc_attr(&screen->ri, 0, 0, 0, attrp);
+ screen->ri.ri_ops.pack_attr(&screen->ri, 0, 0, 0, attrp);
return (0);
}
@@ -1402,7 +1402,7 @@ gbe_cnattach(bus_space_tag_t iot, bus_addr_t addr)
/*
* Attach wsdisplay.
*/
- gbe_consdata.ri.ri_ops.alloc_attr(&gbe_consdata.ri, 0, 0, 0, &attr);
+ gbe_consdata.ri.ri_ops.pack_attr(&gbe_consdata.ri, 0, 0, 0, &attr);
wsdisplay_cnattach(&gbe_stdscreen, &gbe_consdata.ri, 0, 0, attr);
gbe_console = 1;
diff --git a/sys/arch/sgi/dev/impact.c b/sys/arch/sgi/dev/impact.c
index 7c181e267e6..0d79d017ca7 100644
--- a/sys/arch/sgi/dev/impact.c
+++ b/sys/arch/sgi/dev/impact.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: impact.c,v 1.9 2017/09/08 05:36:52 deraadt Exp $ */
+/* $OpenBSD: impact.c,v 1.10 2020/05/25 06:45:25 jsg Exp $ */
/*
* Copyright (c) 2010, 2012 Miodrag Vallat.
@@ -448,7 +448,7 @@ impact_alloc_screen(void *v, const struct wsscreen_descr *type,
*cookiep = ri;
*curxp = 0;
*curyp = 0;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &scr->defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &scr->defattr);
*attrp = scr->defattr;
return 0;
@@ -769,7 +769,7 @@ impact_cnattach_common(bus_space_tag_t iot, bus_space_handle_t ioh, int has_hq4)
if (rc != 0)
return rc;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &scr->defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &scr->defattr);
wsdisplay_cnattach(&scr->wsd, ri, 0, 0, scr->defattr);
return 0;
diff --git a/sys/arch/sgi/gio/grtwo.c b/sys/arch/sgi/gio/grtwo.c
index 85065c79453..527f003ec30 100644
--- a/sys/arch/sgi/gio/grtwo.c
+++ b/sys/arch/sgi/gio/grtwo.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: grtwo.c,v 1.13 2017/01/15 20:22:33 fcambus Exp $ */
+/* $OpenBSD: grtwo.c,v 1.14 2020/05/25 06:45:25 jsg Exp $ */
/* $NetBSD: grtwo.c,v 1.11 2009/11/22 19:09:15 mbalmer Exp $ */
/*
@@ -469,7 +469,7 @@ grtwo_cnattach(struct gio_attach_args *ga)
if (rc != 0)
return rc;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &defattr);
cell = grtwo_console_bs;
for (i = ri->ri_cols * ri->ri_rows; i != 0; i--, cell++)
cell->attr = defattr;
@@ -828,7 +828,7 @@ grtwo_alloc_screen(void *v, const struct wsscreen_descr * type, void **cookiep,
*cookiep = ri;
*curxp = *curyp = 0;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &dc->dc_defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &dc->dc_defattr);
*attrp = dc->dc_defattr;
cell = dc->dc_bs;
diff --git a/sys/arch/sgi/gio/light.c b/sys/arch/sgi/gio/light.c
index 39a77a58fe6..5d221623cf9 100644
--- a/sys/arch/sgi/gio/light.c
+++ b/sys/arch/sgi/gio/light.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: light.c,v 1.8 2017/01/15 20:22:33 fcambus Exp $ */
+/* $OpenBSD: light.c,v 1.9 2020/05/25 06:45:25 jsg Exp $ */
/* $NetBSD: light.c,v 1.5 2007/03/04 06:00:39 christos Exp $ */
/*
@@ -447,7 +447,7 @@ light_cnattach(struct gio_attach_args *ga)
light_attach_common(&light_console_dc, ga);
light_init_screen(&light_console_dc);
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &defattr);
wsdisplay_cnattach(&light_console_dc.dc_wsd, ri, 0, 0, defattr);
return 0;
@@ -743,7 +743,7 @@ light_alloc_screen(void *v, const struct wsscreen_descr *type, void **cookiep,
*cookiep = ri;
*curxp = *curyp = 0;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &dc->dc_defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &dc->dc_defattr);
*attrp = dc->dc_defattr;
return 0;
diff --git a/sys/arch/sgi/gio/newport.c b/sys/arch/sgi/gio/newport.c
index 97e0f43597e..dfc31e78f06 100644
--- a/sys/arch/sgi/gio/newport.c
+++ b/sys/arch/sgi/gio/newport.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: newport.c,v 1.11 2017/01/15 20:22:33 fcambus Exp $ */
+/* $OpenBSD: newport.c,v 1.12 2020/05/25 06:45:25 jsg Exp $ */
/* $NetBSD: newport.c,v 1.15 2009/05/12 23:51:25 macallan Exp $ */
/*
@@ -588,7 +588,7 @@ newport_cnattach(struct gio_attach_args *ga)
if (rc != 0)
return rc;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &defattr);
wsdisplay_cnattach(&newport_console_dc.dc_wsd, ri, 0, 0, defattr);
return 0;
@@ -823,7 +823,7 @@ newport_alloc_screen(void *v, const struct wsscreen_descr *type,
*cookiep = ri;
*curxp = *curyp = 0;
- ri->ri_ops.alloc_attr(ri, 0, 0, 0, &dc->dc_defattr);
+ ri->ri_ops.pack_attr(ri, 0, 0, 0, &dc->dc_defattr);
*attrp = dc->dc_defattr;
return 0;
diff --git a/sys/arch/sgi/xbow/odyssey.c b/sys/arch/sgi/xbow/odyssey.c
index 64c46aee053..d606eff1140 100644
--- a/sys/arch/sgi/xbow/odyssey.c
+++ b/sys/arch/sgi/xbow/odyssey.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: odyssey.c,v 1.12 2017/09/08 05:36:52 deraadt Exp $ */
+/* $OpenBSD: odyssey.c,v 1.13 2020/05/25 06:45:25 jsg Exp $ */
/*
* Copyright (c) 2009, 2010 Joel Sing <jsing@openbsd.org>
*
@@ -672,7 +672,7 @@ odyssey_alloc_screen(void *v, const struct wsscreen_descr *type,
*curyp = 0;
/* Correct screen attributes. */
- screen->ri.ri_ops.alloc_attr(&screen->ri, 0, 0, 0, attrp);
+ screen->ri.ri_ops.pack_attr(&screen->ri, 0, 0, 0, attrp);
screen->attr = *attrp;
return (0);
@@ -1135,7 +1135,7 @@ odyssey_cnattach()
/*
* Attach wsdisplay.
*/
- screen->ri.ri_ops.alloc_attr(&screen->ri, 0, 0, 0, &screen->attr);
+ screen->ri.ri_ops.pack_attr(&screen->ri, 0, 0, 0, &screen->attr);
wsdisplay_cnattach(&odyssey_stdscreen, &screen->ri, 0, 0, screen->attr);
return 0;
diff --git a/sys/arch/sparc64/dev/creator.c b/sys/arch/sparc64/dev/creator.c
index 8edeb55c36c..9c090cd504c 100644
--- a/sys/arch/sparc64/dev/creator.c
+++ b/sys/arch/sparc64/dev/creator.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: creator.c,v 1.51 2017/09/08 05:36:52 deraadt Exp $ */
+/* $OpenBSD: creator.c,v 1.52 2020/05/25 06:45:25 jsg Exp $ */
/*
* Copyright (c) 2002 Jason L. Wright (jason@thought.net)
@@ -248,7 +248,7 @@ creator_ioctl(v, cmd, data, flags, p)
creator_ras_init(sc);
/* Clear screen. */
- ri->ri_ops.alloc_attr(ri,
+ ri->ri_ops.pack_attr(ri,
WSCOL_BLACK, WSCOL_WHITE, WSATTR_WSCOLORS, &attr);
ri->ri_ops.eraserows(ri, 0, ri->ri_rows, attr);
}
diff --git a/sys/arch/sparc64/dev/fb.c b/sys/arch/sparc64/dev/fb.c
index 4cc28492c86..20866cce071 100644
--- a/sys/arch/sparc64/dev/fb.c
+++ b/sys/arch/sparc64/dev/fb.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: fb.c,v 1.28 2016/03/29 22:06:50 kettenis Exp $ */
+/* $OpenBSD: fb.c,v 1.29 2020/05/25 06:45:25 jsg Exp $ */
/* $NetBSD: fb.c,v 1.23 1997/07/07 23:30:22 pk Exp $ */
/*
@@ -363,10 +363,10 @@ fbwscons_console_init(struct sunfb *sf, int row)
cookie = ri;
if (ISSET(ri->ri_caps, WSSCREEN_WSCOLORS))
- ri->ri_ops.alloc_attr(cookie,
+ ri->ri_ops.pack_attr(cookie,
WSCOL_BLACK, WSCOL_WHITE, WSATTR_WSCOLORS, &defattr);
else
- ri->ri_ops.alloc_attr(cookie, 0, 0, 0, &defattr);
+ ri->ri_ops.pack_attr(cookie, 0, 0, 0, &defattr);
fb_initwsd(sf);
wsdisplay_cnattach(&sf->sf_wsd, cookie,
@@ -462,10 +462,10 @@ fb_alloc_screen(void *v, const struct wsscreen_descr *type,
*curyp = 0;
*curxp = 0;
if (ISSET(ri->ri_caps, WSSCREEN_WSCOLORS))
- ri->ri_ops.alloc_attr(cookie,
+ ri->ri_ops.pack_attr(cookie,
WSCOL_BLACK, WSCOL_WHITE, WSATTR_WSCOLORS, attrp);
else
- ri->ri_ops.alloc_attr(cookie, 0, 0, 0, attrp);
+ ri->ri_ops.pack_attr(cookie, 0, 0, 0, attrp);
sf->sf_nscreens++;
return (0);
}
diff --git a/sys/arch/luna88k/dev/omrasops.c b/sys/arch/luna88k/dev/omrasops.c
index 5c7cb6f2b15..70328f2df3e 100644
--- a/sys/arch/luna88k/dev/omrasops.c
+++ b/sys/arch/luna88k/dev/omrasops.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: omrasops.c,v 1.14 2017/03/20 19:37:54 miod Exp $ */
+/* $OpenBSD: omrasops.c,v 1.15 2020/05/25 06:45:25 jsg Exp $ */
/* $NetBSD: omrasops.c,v 1.1 2000/01/05 08:48:56 nisimura Exp $ */
/*-
@@ -74,7 +74,7 @@ int om4_windowmove(struct rasops_info *, u_int16_t, u_int16_t, u_int16_t,
u_int16_t, u_int16_t, u_int16_t, int16_t, int16_t);
/* MI function in src/sys/dev/rasops/rasops.c */
-int rasops_alloc_cattr(void *, int, int, int, long *);
+int rasops_pack_cattr(void *, int, int, int, long *);
static int (*om_windowmove)(struct rasops_info *, u_int16_t, u_int16_t,
u_int16_t, u_int16_t, u_int16_t, u_int16_t, int16_t, int16_t);
@@ -534,8 +534,8 @@ setup_omrasops4(struct rasops_info *ri)
= WSSCREEN_HILIT | WSSCREEN_WSCOLORS | WSSCREEN_REVERSE;
/*
* Since we set ri->ri_depth == 1, rasops_init() set
* rasops_alloc_mattr for us. But we use the color version,
* rasops_alloc_cattr, on 4bpp/8bpp frame buffer.
*/
- ri->ri_ops.alloc_attr = rasops_alloc_cattr;
+ ri->ri_ops.pack_attr = rasops_pack_cattr;
}
@@ -534,8 +534,8 @@ setup_omrasops4(struct rasops_info *ri)
/*
* Since we set ri->ri_depth == 1, rasops_init() set
- * rasops_alloc_mattr for us. But we use the color version,
- * rasops_alloc_cattr, on 4bpp/8bpp frame buffer.
+ * rasops_pack_mattr for us. But we use the color version,
+ * rasops_pack_cattr, on 4bpp/8bpp frame buffer.
*/